@@ -132,7 +132,9 @@ class URL(str):
 
     @property
     def host_no_www(self) -> str:
-        return self.host.lstrip("www.")
+        if self.host.startswith("www."):
+            return self.host[4:]
+        return self.host
 
     @property
     def unicode_host(self) -> str | None:
